@@ -22,25 +22,23 @@
 
 #include <stdarg.h>
 
-#ifdef HAVE_NCURSES
+#if defined(HAVE_NCURSES_H) && defined(HAVE_TERM_H)
 #include <ncurses.h>
 #include <term.h>
-#define HAVE_CURSES
-#else
-#ifdef HAVE_NCURSES_CURSES
+#define VTE_TERMCAP_NAME "ncurses"
+#elif defined(HAVE_NCURSES_CURSES_H) && defined(HAVE_NCURSES_TERM_H)
 #include <ncurses/curses.h>
 #include <ncurses/term.h>
-#define HAVE_CURSES
-#else
-#ifdef HAVE_CURSES
+#define VTE_TERMCAP_NAME "ncurses"
+#elif defined(HAVE_CURSES_H) && defined(HAVE_TERM_H)
 #include <curses.h>
 #include <term.h>
-#else
-#ifdef HAVE_TERMCAP
+#define VTE_TERMCAP_NAME "curses"
+#elif defined(HAVE_TERMCAP_H)
 #include <termcap.h>
-#endif
-#endif
-#endif
+#define VTE_TERMCAP_NAME "termcap"
+#else
+#error No termcap??
 #endif
 
 #include <sys/types.h>
